#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-splice-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-splice-plugin-2.3.0.0-F651i8bo9ytCX0BjmP6s8l
key:                  hls-splice-plugin-2.3.0.0-F651i8bo9ytCX0BjmP6s8l
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:
    HLS Plugin to expand TemplateHaskell Splices and QuasiQuotes

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  1051e10dbd9c49140018824154a9bcd3
exposed:              True
exposed-modules:      Ide.Plugin.Splice Ide.Plugin.Splice.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-splice-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-splice-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-splice-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-splice-plugin
hs-libraries:         HShls-splice-plugin-2.3.0.0-F651i8bo9ytCX0BjmP6s8l
depends:
    aeson-2.2.1.0-FEnGzvKMunxDwDFhBeJYHO base-4.18.2.1 containers-0.6.7
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    extra-1.7.16-GBHSV2ca01pLlBBatrwGfL
    foldl-1.4.18-43mIPfUO3PcD67vVENrkoo ghc-9.6.6
    ghc-exactprint-1.7.1.0-EBzWzdIl7xt3bwssYl9Wwe
    ghcide-2.3.0.0-QtCqgkAhjlupfC2pm4el
    hls-plugin-api-2.3.0.0-D6yfjm5Qm5fLxsApgswhjH
    hls-refactor-plugin-2.3.0.0-CaoW6oggy2K7WlUaepSEdf
    lens-5.3.4-B9QPRzrMZ8J355CXfNFvnN
    lsp-2.2.0.0-81EvswuDs4iK20QcL1dFFp mtl-2.3.1
    retrie-1.2.3-DLKqR7PoIf0Ghx3yYsmEJ syb-0.7.3-H7QXegMKksQGc4JgI4csk0
    text-2.0.2 transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-2pZfUb3hQF1KSawFItMd4V

haddock-interfaces:
    /usr/share/doc/haskell-hls-splice-plugin/html/hls-splice-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-splice-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

